;;
;; Spotted/theme.jl		(Spotted 0.0.1 for sawfish 0.27.2)
;;
;; by Zinx Verituse <zinx@linuxfreak.com>
;;

(defgroup spotted-zinx "Spotted Theme"
	:group appearance)

(defcustom spotted-zinx:font "-*-lucida-medium-r-normal-*-*-100-*-*-p-*-iso8859-1"
	"Titlebar font"
	:type font
	:group (appearance spotted-zinx)
	:after-set after-setting-frame-option)

(defcustom spotted-zinx:title-active-fg "rgb:c/c/c"
	"Active title foreground"
	:type color
	:group (appearance spotted-zinx)
	:after-set after-setting-frame-option)

(defcustom spotted-zinx:title-active-bg "black"
	"Active title background"
	:type color
	:group (appearance spotted-zinx)
	:after-set after-setting-frame-option)

(defcustom spotted-zinx:title-inactive-fg "grey50"
	"Inactive title foreground"
	:type color
	:group (appearance spotted-zinx)
	:after-set after-setting-frame-option)

(defcustom spotted-zinx:title-inactive-bg "black"
	"Inactive title background"
	:type color
	:group (appearance spotted-zinx)
	:after-set after-setting-frame-option)

(let*
    (
	(title-font (lambda (w) (list spotted-zinx:font)))
	(title-fg (lambda (w) (list spotted-zinx:title-inactive-fg spotted-zinx:title-active-fg)))
	(title-bg (lambda (w) (list spotted-zinx:title-inactive-bg spotted-zinx:title-active-bg)))

	;; The title bar...
	(titlebar-left (make-image "spot-bar-left.png"))
	(titlebar-right (make-image "spot-bar-right.png"))
	(titlebar-top (make-image "spot-bar-top.png"))
	(titlebar-bottom (make-image "spot-bar-bottom.png"))

	;; The buttons...
	(button-menu (make-image "spot-button-menu.png"))
	(button-iconify (make-image "spot-button-minimize.png"))
	(button-close (make-image "spot-button-close.png"))

	(resizer (make-image "spot-resize.png"))

	(titlebar
	`(
	   ((background . ,titlebar-left)
	    (top-edge . -13)
	    (left-edge . -5)
	    (class . title))
	   ((background . ,titlebar-top)
	    (top-edge . -13)
	    (left-edge . 23)
	    (right-edge . 71)
	    (class . title))
	   ((background . ,titlebar-bottom)
	    (top-edge . -1)
	    (left-edge . 23)
	    (right-edge . 71)
	    (class . title))

	   ((background . ,title-bg)
	    (foreground . ,title-fg)
	    (font . ,title-font)
	    (text . ,window-name)
	    (x-justify . center)
	    (y-justify . center)
	    (top-edge . -12)
	    (height . 11)
	    (left-edge . 23)
	    (right-edge . 71)
	    (class . title))

	   ((background . ,titlebar-right)
	    (top-edge . -13)
	    (right-edge . -5)
	    (class . title))
	  )
	 )

	(buttons
	 `(
	   ((background . ,button-menu)
	    (top-edge . -14)
	    (right-edge . 48)
	    (class . menu-button))
	   ((background . ,button-iconify)
	    (top-edge . -14)
	    (right-edge . 31)
	    (class . iconify-button))
	   ((background . ,button-close)
	    (top-edge . -14)
	    (right-edge . 13)
	    (class . close-button))
	  )
	 )

	(borders
	 `(
	   ((background . "black")
	    (top-edge . 0)
	    (bottom-edge . 0)
	    (left-edge . -1)
	    (width . 1))
	   ((background . "black")
	    (top-edge . 0)
	    (bottom-edge . 0)
	    (right-edge . -1)
	    (width . 1))
	   ((background . "black")
	    (left-edge . -1)
	    (right-edge . -1)
	    (bottom-edge . -1)
	    (height . 1))

	   ((background . ,resizer)
	    (bottom-edge . -7)
	    (right-edge . -6)
	    (removable . t)
	    (class . bottom-right-corner))
	  )
	 )

	(frame `(,@titlebar ,@buttons ,@borders))
	(transient-frame `(,@titlebar ,@borders))
	(shaped-frame `(,@titlebar ,@buttons))
	(shaped-transient-frame `(,@titlebar))
    )

    (add-frame-style 'Spotted
     (lambda (w type)
	(cond ((eq type 'unframed) nil-frame)
	      ((eq type 'transient) transient-frame)
	      ((eq type 'shaped) shaped-frame)
	      ((eq type 'shaped-transient) shaped-transient-frame)
	      (t frame))
     )
    )
)

